@@ -62,7 +62,7 @@ class dyagram:
                                       "username": self.username,
                                       "password": self.password,
                                       "secret": self.password,
-                                      "global_delay": 3,
+
                                       "banner_timeout": 200}
 
 
@@ -264,8 +264,7 @@ class dyagram:
                             "username": self.username,
                             "password": self.password,
                             "secret": self.password,
-                            "banner_timeout": 200,
-                            "global_delay": 3
+                            "banner_timeout": 200
                             }
             # autodetect_tries = 0
             # while autodetect_tries < 10:
@@ -329,15 +328,14 @@ class dyagram:
 
 
     def get_device_type(self, device):
-        #time.sleep(5)  # FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
+
         try:
 
             autodetect_netmiko_args = {"device_type": "autodetect",
                                        "host": device,
                                        "username": self.username,
                                        "password": self.password,
-                                       "banner_timeout": 30,
-                                       "global_delay": 3}
+                                       "banner_timeout": 30}
             autodetect_tries = 0
             while autodetect_tries < 10:
                 try:
@@ -397,6 +395,7 @@ class dyagram:
 
         try:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering EIGRP Neighbors - START")
+            time.sleep(5)  # FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
             discovered = self.discover_eigrp_neighbors_restconf()
 
             if not discovered:
@@ -918,3 +917,4 @@ def main():
 
 if __name__ == "__main__":
     main()
+
